package com.gree.mall.manager.logic.contract;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gree.mall.manager.bean.admin.AdminUserCom;
import com.gree.mall.manager.bean.contract.ContractTemplateBean;
import com.gree.mall.manager.bean.contract.ContractTemplateVO;
import com.gree.mall.manager.bean.contract.ContractWebsitBean;
import com.gree.mall.manager.commonmapper.CommonMapper;
import com.gree.mall.manager.enums.ContractTypeEnum;
import com.gree.mall.manager.exception.RemoteServiceException;
import com.gree.mall.manager.logic.common.CommonLogic;
import com.gree.mall.manager.plus.entity.ContractTemplate;
import com.gree.mall.manager.plus.service.AdminWebsitService;
import com.gree.mall.manager.plus.service.ContractTemplateService;
import com.gree.mall.manager.plus.service.ContractWebsitService;
import com.gree.mall.manager.zfire.bean.ZfireParamBean;
import com.gree.mall.manager.zfire.util.FieldUtils;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Slf4j
@Service
@RequiredArgsConstructor
public class ContractTemplateLogic {
    private final CommonLogic commonLogic;
    private final CommonMapper commonMapper;
    private final ContractTemplateService contractTemplateService;
    private final ContractWebsitService contractWebsitService;
    private final AdminWebsitService adminWebsitService;

    public IPage<ContractTemplateVO> list(ZfireParamBean zfireParamBean) {
        AdminUserCom adminUser = commonLogic.getAdminUser();
        FieldUtils.supplyParam(zfireParamBean, ContractTemplateVO.class, adminUser);
        return commonMapper.contractTemplatePage(new Page(zfireParamBean.getPageNum(), zfireParamBean.getPageSize()), zfireParamBean);
    }

    public ContractTemplateBean detail(String contractTemplateId) {
        AdminUserCom adminUser = commonLogic.getAdminUser();
        final ContractTemplate template = contractTemplateService.getById(contractTemplateId);
        ContractTemplateBean bean = new ContractTemplateBean();
        BeanUtils.copyProperties(template, bean);
        // 查询已选子网点
        List<ContractWebsitBean> websitBeanList = commonMapper.contractWebsitList(contractTemplateId);
        bean.setItems(websitBeanList);

        return bean;
    }

    public IPage<ContractWebsitBean> queryRelaWebsit(String contractTemplateId, String websitId, String websitName,
                                                     Integer pageNum, Integer pageSize) {
        AdminUserCom adminUser = commonLogic.getAdminUser();
        IPage<ContractWebsitBean> page = commonMapper.querySettleRelaWebsit(new Page<>(pageNum, pageSize), contractTemplateId, websitId, websitName);
        return page;
    }

    @Transactional
    public void add(ContractTemplateBean contractTemplate) {
        this.validRequireParams(contractTemplate);
    }

    private void validRequireParams(ContractTemplateBean contractTemplate) {
        if (StringUtils.isBlank(contractTemplate.getContractTemplateName())) {
            throw new RemoteServiceException("合同名称不能为空");
        }
        if (StringUtils.isBlank(contractTemplate.getContractType())) {
            throw new RemoteServiceException("合同类型不能为空");
        }
        if (contractTemplate.getContractType().equals(ContractTypeEnum.FOLLOW.getKey())) {
            contractTemplate.
        }
    }
}
